# This file is generated by SciPy's build process
# It contains system_info results at the time of building this package.
from enum import Enum

__all__ = ["show"]
_built_with_meson = True


class DisplayModes(Enum):
    stdout = "stdout"
    dicts = "dicts"


def _cleanup(d):
    """
    Removes empty values in a `dict` recursively
    This ensures we remove values that Meson could not provide to CONFIG
    """
    if isinstance(d, dict):
        return { k: _cleanup(v) for k, v in d.items() if v != '' and _cleanup(v) != '' }
    else:
        return d


CONFIG = _cleanup(
    {
        "Compilers": {
            "c": {
                "name": "gcc",
                "linker": "ld.bfd",
                "version": "13.2.1",
                "commands": "cc",
                "args": "-march=x86-64, -mtune=generic, -O2, -pipe, -fno-plt, -fexceptions, -Wp,-D_FORTIFY_SOURCE=2, -Wformat, -Werror=format-security, -fstack-clash-protection, -fcf-protection, -flto=auto",
                "linker args": "-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now, -flto=auto, -march=x86-64, -mtune=generic, -O2, -pipe, -fno-plt, -fexceptions, -Wp,-D_FORTIFY_SOURCE=2, -Wformat, -Werror=format-security, -fstack-clash-protection, -fcf-protection, -flto=auto",
            },
            "cython": {
                "name": "cython",
                "linker": "cython",
                "version": "3.0.8",
                "commands": "cython",
                "args": "",
                "linker args": "",
            },
            "c++": {
                "name": "gcc",
                "linker": "ld.bfd",
                "version": "13.2.1",
                "commands": "c++",
                "args": "-march=x86-64, -mtune=generic, -O2, -pipe, -fno-plt, -fexceptions, -Wp,-D_FORTIFY_SOURCE=2, -Wformat, -Werror=format-security, -fstack-clash-protection, -fcf-protection, -Wp,-D_GLIBCXX_ASSERTIONS, -flto=auto",
                "linker args": "-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now, -flto=auto, -march=x86-64, -mtune=generic, -O2, -pipe, -fno-plt, -fexceptions, -Wp,-D_FORTIFY_SOURCE=2, -Wformat, -Werror=format-security, -fstack-clash-protection, -fcf-protection, -Wp,-D_GLIBCXX_ASSERTIONS, -flto=auto",
            },
            "fortran": {
                "name": "gcc",
                "linker": "ld.bfd",
                "version": "13.2.1",
                "commands": "gfortran",
                "args": "",
                "linker args": "-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now, -flto=auto",
            },
            "pythran": {
                "version": "0.15.0",
                "include directory": r"../../../../../usr/lib/python3.11/site-packages/pythran"
            },
        },
        "Machine Information": {
            "host": {
                "cpu": "x86_64",
                "family": "x86_64",
                "endian": "little",
                "system": "linux",
            },
            "build": {
                "cpu": "x86_64",
                "family": "x86_64",
                "endian": "little",
                "system": "linux",
            },
            "cross-compiled": bool("False".lower().replace('false', '')),
        },
        "Build Dependencies": {
            "blas": {
                "name": "mkl-dynamic-lp64-seq",
                "found": bool("True".lower().replace('false', '')),
                "version": "2023.2",
                "detection method": "pkgconfig",
                "include directory": r"/opt/intel/oneapi/mkl/latest/include",
                "lib directory": r"/opt/intel/oneapi/mkl/latest/lib/intel64",
                "openblas configuration": "unknown",
                "pc file directory": r"/opt/intel/oneapi/mkl/2023.2.0/lib/pkgconfig",
            },
            "lapack": {
                "name": "mkl-dynamic-lp64-seq",
                "found": bool("True".lower().replace('false', '')),
                "version": "2023.2",
                "detection method": "pkgconfig",
                "include directory": r"/opt/intel/oneapi/mkl/latest/include",
                "lib directory": r"/opt/intel/oneapi/mkl/latest/lib/intel64",
                "openblas configuration": "unknown",
                "pc file directory": r"/opt/intel/oneapi/mkl/2023.2.0/lib/pkgconfig",
            },
            "pybind11": {
                "name": "pybind11",
                "version": "2.11.1",
                "detection method": "pkgconfig",
                "include directory": r"/usr/lib/pkgconfig/../..//include",
            },
        },
        "Python Information": {
            "path": r"/usr/bin/python",
            "version": "3.11",
        },
    }
)


def _check_pyyaml():
    import yaml

    return yaml


def show(mode=DisplayModes.stdout.value):
    """
    Show libraries and system information on which SciPy was built
    and is being used

    Parameters
    ----------
    mode : {`'stdout'`, `'dicts'`}, optional.
        Indicates how to display the config information.
        `'stdout'` prints to console, `'dicts'` returns a dictionary
        of the configuration.

    Returns
    -------
    out : {`dict`, `None`}
        If mode is `'dicts'`, a dict is returned, else None

    Notes
    -----
    1. The `'stdout'` mode will give more readable
       output if ``pyyaml`` is installed

    """
    if mode == DisplayModes.stdout.value:
        try:  # Non-standard library, check import
            yaml = _check_pyyaml()

            print(yaml.dump(CONFIG))
        except ModuleNotFoundError:
            import warnings
            import json

            warnings.warn("Install `pyyaml` for better output", stacklevel=1)
            print(json.dumps(CONFIG, indent=2))
    elif mode == DisplayModes.dicts.value:
        return CONFIG
    else:
        raise AttributeError(
            f"Invalid `mode`, use one of: {', '.join([e.value for e in DisplayModes])}"
        )
